#ifndef COMMON_H
#define COMMON_H

#include <Arduino.h>
#include <EEPROM.h>
#include <SD.h>
#include <SPI.h>
#include "LCDHandler.h"
#include "KeypadHandler.h"

// SD card control pin
#define SD_CS_PIN 22

// EEPROM address for settings
#define EEPROM_SETTINGS_ADDR 0
#define EEPROM_VALID_FLAG 0xAB  // Flag to check if EEPROM contains valid settings

// Baud rate options
#define BAUD_COUNT 11
extern const long BAUD_RATES[BAUD_COUNT];
extern const char* BAUD_NAMES[BAUD_COUNT];

// Data bits options
#define DATA_BITS_COUNT 2
extern const int DATA_BITS_OPTIONS[DATA_BITS_COUNT];

// Parity options
#define PARITY_COUNT 3
typedef enum {
    PARITY_NONE,
    PARITY_ODD,
    PARITY_EVEN
} ParityType;
extern const char* PARITY_NAMES[PARITY_COUNT];

// Stop bits options
#define STOP_BITS_COUNT 2
extern const float STOP_BITS_OPTIONS[STOP_BITS_COUNT];
extern const char* STOP_BITS_NAMES[STOP_BITS_COUNT];

// File navigation keys (reuse menu keys)
#define KEY_UP 'U'
#define KEY_DOWN 'D'
#define KEY_LEFT 'L'
#define KEY_RIGHT 'R'
#define KEY_ENTER 'O'
#define KEY_ESCAPE 'E'
#define KEY_BACKSPACE 'B'

// Serial settings structure
typedef struct {
    uint8_t validFlag;     // Flag to verify settings are valid
    uint8_t baudRateIndex; // Index into BAUD_RATES array
    uint8_t dataBitsIndex; // Index into DATA_BITS_OPTIONS array
    uint8_t parityIndex;   // Index into PARITY_NAMES array
    uint8_t stopBitsIndex; // Index into STOP_BITS_OPTIONS array
    bool flowControlEnabled; // RTS/CTS flow control
    char currentFileName[13]; // 8.3 filename format + null terminator
} SerialSettings;

// Global settings object
extern SerialSettings serialSettings;

// Function declarations
void loadSettingsFromEEPROM();
void saveSettingsToEEPROM();
void setDefaultSettings();

// SD card functions
bool initSDCard();
String selectFileFromSD();
String inputFileName();
void saveCurrentFileName(const String &fileName);

#endif // COMMON_H