#ifndef MENUS_H
#define MENUS_H

#include <Arduino.h>
#include "LCDHandler.h"
#include "KeypadHandler.h"

// Menu navigation keys
#define KEY_UP 'U'
#define KEY_DOWN 'D'
#define KEY_LEFT 'L'
#define KEY_RIGHT 'R'
#define KEY_ENTER 'O'    // O = enter
#define KEY_ESCAPE 'E'   // E = escape
#define KEY_F1 'A'       // A = F1
#define KEY_F2 'B'       // B = F2

// Maximum number of menu items per level
#define MAX_MENU_ITEMS 10

// Menu item structure
typedef struct {
    String title;
    void (*action)();
    uint8_t subMenuId;  // ID of submenu (0 = no submenu)
} MenuItem;

// Menu structure
typedef struct {
    String title;
    uint8_t itemCount;
    MenuItem items[MAX_MENU_ITEMS];
    uint8_t parentMenuId;  // ID of parent menu (0 = main menu)
} Menu;

// Function declarations for menu system
void initMenuSystem();
void displayMenu();
void handleMenuNavigation();
void executeMenuAction();
void navigateToMenu(uint8_t menuId);
void registerMenu(uint8_t menuId, const String &title, uint8_t parentMenuId);
void addMenuItem(uint8_t menuId, const String &title, void (*action)(), uint8_t subMenuId);
void showHelp();
void showQuickActions();

// Function declarations for CNC operations
void sendCNCProgram();
void receiveProgram();
void browseSDFiles();
void showAboutInfo();

// Function declarations for RS232 settings
void rs232SettingsMenu();
void setBaudRate();
void setDataBits();
void setParity();
void setStopBits();
void setFlowControl();  // Added for RTS/CTS flow control
void saveSerialSettings();

#endif // MENUS_H